TestAddLocationStrategy
open | ../tests/html/test_click_page1.html |
addLocationStrategy | foo | return inDocument.getElementById(locator);
assertElementPresent | foo=link |
refreshAndWait |  |
assertElementPresent | foo=link |
assertErrorOnNext | Error evaluating function definition* |
addLocationStrategy | bar | [[[;
addLocationStrategy | bar | thisVariableDoesNotExist;
assertErrorOnNext | Error executing strategy function bar* |
assertElementPresent | bar=link |